<?php
  /**
   * Classe Cadastro
   *
   * @package Sistemas Divulgao Online
   * @author Geandro Bessa
   * @copyright 2013
   * @version 2
   */
  
  if (!defined("_VALID_PHP"))
      die('Acesso direto a esta classe no  permitido.');

  class Cadastro
  {
      const uTable = "cadastro";
      public $did = 0;
      public $cadastroid = 0;
      private static $db;

      /**
       * Cadastro::__construct()
       * 
       * @return
       */
      function __construct()
      {
          self::$db = Registry::get("Database");
      }

      /**
       * Cadastro::getCadastros()
       * 
       * @return
       */
      public function getCadastros()
      {
		  $sql = "SELECT id, nome, documento, razao_social, contato, telefone, celular, email, endereco, numero, cidade, convenio, contrato FROM cadastro WHERE inativo = 0 ORDER BY nome, razao_social ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Cadastro::getFornecedores()
       * 
       * @return
       */
      public function getFornecedores()
      {
		  $sql = "SELECT id, nome, documento, razao_social, contato, telefone, celular, email, endereco, numero, cidade, convenio, contrato FROM cadastro WHERE inativo = 0 and convenio = 0 ORDER BY nome, razao_social ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Cadastro::getConvenios()
       * 
       * @return
       */
      public function getConvenios()
      {
		  $sql = "SELECT id, nome, documento, razao_social, contato, telefone, celular, email, endereco, numero, cidade, convenio, contrato, '1' AS principal FROM cadastro WHERE inativo = 0 AND (convenio in (1,2) OR contrato = 1) ORDER BY nome, razao_social ASC ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Cadastro::getConveniosReceber()
       * 
       * @return
       */
      public function getConveniosReceber()
      {
		  $sql = "SELECT id, nome, documento, razao_social, contato, telefone, celular, email, endereco, numero, cidade, convenio, contrato FROM cadastro WHERE inativo = 0 AND convenio = 2 ORDER BY nome, razao_social ASC ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Cadastro::getConveniosPacientes()
       * 
       * @return
       */
      public function getConveniosPacientes($id_paciente = false)
      {
		  $sql = "SELECT c.id, c.nome, p.id_paciente, p.id_convenio, p.principal FROM cadastro as c, paciente_convenio as p WHERE c.inativo = 0 AND (c.convenio in (1,2) OR c.contrato = 1) AND p.inativo = 0 AND c.id = p.id_convenio AND p.id_paciente = '$id_paciente' ORDER BY p.principal DESC, nome ASC, razao_social ASC ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }

      /**
       * Cadastro::getLaboratorios()
       * 
       * @return
       */
      public function getLaboratorios()
      {
		  $sql = "SELECT id, nome, documento, razao_social, contato, telefone, celular, email, endereco, numero, cidade, convenio, contrato FROM cadastro WHERE inativo = 0 AND convenio = 3 ORDER BY nome, razao_social ASC ";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
      /**
       * Cadastro::processarCadastro()
       * contrato: 1 - CONVENIO PROPRIO
	   *
       * convenio: 1 - CONVENIO A PAGAR
       * convenio: 2 - CONVENIO A RECEBER
       * convenio: 3 - LABORATORIO
       * @return
       */
      public function processarCadastro()
      {
		  $cpf_cnpj = limparCPF_CNPJ(post('cpf_cnpj'));
		  
		  if($cpf_cnpj == '11111111111111' or trim($cpf_cnpj) == '') {
				  $cpf_cnpj = 'NULL';		  
		  } else {
			  $where = (Filter::$id) ? "AND id <> ".Filter::$id : "";
			  $sql = "SELECT nome FROM cadastro WHERE cpf_cnpj = '$cpf_cnpj' $where ";
			  $row = self::$db->first($sql);
			  
			  if ($row)
				  Filter::$msgs['cpf_cnpj'] = str_replace("[NOME]", $row->nome, lang('MSG_ERRO_CPF_CNPJ_CADASTRADO'));
		  }		  
		  
		  if (empty($_POST['nome']))
              Filter::$msgs['nome'] = lang('MSG_ERRO_NOME');				  

          if (empty(Filter::$msgs)) {
			  
              $data = array(
					'id_empresa' => session('idempresa'),
					'nome' => sanitize(post('nome')), 
					'razao_social' => sanitize(post('razao_social')), 
					'documento' => sanitize(post('documento')),
					'contato' => sanitize(post('contato')),
					'id_especialidade' => sanitize(post('id_especialidade')),
					'tipo' => sanitize(post('tipo')), 
					'cpf_cnpj' => $cpf_cnpj,  
					'email' => sanitize(post('email')),
					'cep' => sanitize(post('cep')),
					'endereco' => sanitize(post('endereco')),
					'numero' => sanitize(post('numero')), 
					'complemento' => sanitize(post('complemento')),  
					'bairro' => sanitize(post('bairro')),
					'cidade' => sanitize(post('cidade')), 
					'estado' => sanitize(post('estado')), 
					'ie' => sanitize(post('ie')), 
					'telefone' => sanitize(post('telefone')), 
					'celular' => sanitize(post('celular')), 
					'titular' => sanitize(post('titular')), 
					'banco' => sanitize(post('banco')),
					'agencia' => sanitize(post('agencia')),
					'conta' => sanitize(post('conta')),
					'observacao' => sanitize(post('observacao')),
					'convenio' => post('convenio'),
					'pagamento' => post('pagamento'),
					'valor' => converteMoeda(post('valor')),
					'percentual' => converteMoeda(post('percentual')),
					'inativo' => '0',
					'usuario' => session('nomeusuario'),
					'data' => "NOW()"
			  );

              if(Filter::$id) {
				self::$db->update(self::uTable, $data, "id=" . Filter::$id);
			  } else {
				$data['data_cadastro'] = "NOW()";
				self::$db->insert(self::uTable, $data);
			  }
              $message = (Filter::$id) ? lang('CADASTRO_AlTERADO_OK') : lang('CADASTRO_ADICIONADO_OK');
			  $redirecionar = (empty($_POST['colaborador'])) ? "index.php?do=cadastro&acao=listar" : "index.php?do=colaborador&acao=listar";

              if (self::$db->affected()) {
				Filter::msgOk($message, $redirecionar);  
              } else
                  Filter::msgAlert(lang('NAOPROCESSADO'));
          } else
              print Filter::msgStatus();
      }

      /**
       * Cadastro::getBuscarCadastro()
       * 
       * @return
       */
      public function getBuscarCadastro()
      {
		  $row = false;
		  $nome = post('nome');
		  $cpf = limparCPF_CNPJ(post('cpf'));	  
		  if($nome) {
			$cli = explode(" ", $nome);
			$wherecli = "";
			$count = count($cli);
			for ($i = 0; $i < $count; $i++) {
				$wherecli .= " AND (c.nome LIKE '%".$cli[$i]."%' OR c.razao_social LIKE '%".$cli[$i]."%')";
			}
		  }
		  if($cpf) {
			$sql = "SELECT c.id, c.nome, c.documento, c.razao_social, c.cpf_cnpj, c.celular, c.email, c.telefone, c.bairro, c.cidade, c.usuario, c.data_cadastro, c.inativo " 
		  . "\n FROM cadastro as c"
		  . "\n WHERE cpf_cnpj LIKE '%".$cpf."%' " 
		  . "\n ORDER BY c.nome ";
			$row = self::$db->fetch_all($sql);
		  } elseif($nome) {
			$sql = "SELECT c.id, c.nome, c.documento, c.razao_social, c.cpf_cnpj, c.celular, c.email, c.telefone, c.bairro, c.cidade, c.usuario, c.data_cadastro, c.inativo " 
		  . "\n FROM cadastro as c"
		  . "\n WHERE c.inativo < 2 $wherecli " 
		  . "\n ORDER BY c.nome ";
			$row = self::$db->fetch_all($sql);
		  }

          return ($row) ? $row : 0;
      }
	  
      /**
       * Cadastro::getEspecialidades()
       * 
       * @return
       */
      public function getEspecialidades()
      {
		  $sql = "SELECT id, nome, desconto, medico FROM especialidade WHERE inativo = 0 ORDER BY nome";
          $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
      /**
       * Cadastro::processarEspecialidade()
       * 
       * @return
       */
      public function processarEspecialidade()
      {
		  if (empty($_POST['nome']))
              Filter::$msgs['nome'] = lang('MSG_ERRO_NOME');	  

          if (empty(Filter::$msgs)) {

              $data = array(
					'nome' => sanitize(post('nome')),
					'desconto' => post('desconto'),
					'medico' => post('medico')
			  );

              (Filter::$id) ? self::$db->update("especialidade", $data, "id=" . Filter::$id) : self::$db->insert("especialidade", $data);
              $message = (Filter::$id) ? lang('ESPECIALIDADE_ALTERADO_OK') : lang('ESPECIALIDADE_ADICIONADO_OK');

              if (self::$db->affected()) {
			  
                  Filter::msgOk($message, "index.php?do=especialidade&acao=listar");    
              } else
                  Filter::msgAlert(lang('NAOPROCESSADO'));
          } else
              print Filter::msgStatus();
      }
	  
	  /**
       * Gestao::getEnderecos()
       * 
       * @return
       */
      public function getEnderecos()
      {	
		 $sql = "SELECT id, endereco, bairro, cidade, estado, cep " 
		  . "\n FROM paciente " 
		  . "\n WHERE mapa = 0 limit 1200";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
	  
	  /**
       * Gestao::getMapa()
       * 
       * @return
       */
      public function getMapa()
      {	
		 $sql = "SELECT id, nome, lat, lng " 
		  . "\n FROM paciente " 
		  . "\n WHERE mapa = 1";
		  $row = self::$db->fetch_all($sql);

          return ($row) ? $row : 0;
      }
  }
?>